summaryrefslogtreecommitdiffstats
path: root/sync/internal_api/sync_manager_impl.h
diff options
context:
space:
mode:
authordcheng@chromium.org <dcheng@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-08-28 03:17:58 +0000
committerdcheng@chromium.org <dcheng@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-08-28 03:17:58 +0000
commita329cb82a4627bea79c0db5dabe09698ad83c27e (patch)
treeca12b48cef0de11d3058bee683e082281f5061ec /sync/internal_api/sync_manager_impl.h
parent3c6babd32ae5b7e8125ac16ee4e686654bcf59d6 (diff)
downloadchromium_src-a329cb82a4627bea79c0db5dabe09698ad83c27e.zip
chromium_src-a329cb82a4627bea79c0db5dabe09698ad83c27e.tar.gz
chromium_src-a329cb82a4627bea79c0db5dabe09698ad83c27e.tar.bz2
Rename SyncNotifier->Invalidator and SyncNotifierObserver->InvalidationHandler.
This makes the naming more consistent with how the various classes and interfaces are used, since they are not sync-specific anymore. BUG=none TBR=sky Review URL: https://chromiumcodereview.appspot.com/10875064 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@153619 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'sync/internal_api/sync_manager_impl.h')
-rw-r--r--sync/internal_api/sync_manager_impl.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/sync/internal_api/sync_manager_impl.h b/sync/internal_api/sync_manager_impl.h
index 3a44969..7fa917e7 100644
--- a/sync/internal_api/sync_manager_impl.h
+++ b/sync/internal_api/sync_manager_impl.h
@@ -22,8 +22,8 @@
#include "sync/internal_api/public/sync_manager.h"
#include "sync/internal_api/sync_encryption_handler_impl.h"
#include "sync/js/js_backend.h"
+#include "sync/notifier/invalidation_handler.h"
#include "sync/notifier/notifications_disabled_reason.h"
-#include "sync/notifier/sync_notifier_observer.h"
#include "sync/syncable/directory_change_delegate.h"
#include "sync/util/cryptographer.h"
#include "sync/util/time.h"
@@ -48,7 +48,7 @@ class SyncSessionContext;
// same thread.
class SyncManagerImpl : public SyncManager,
public net::NetworkChangeNotifier::IPAddressObserver,
- public SyncNotifierObserver,
+ public InvalidationHandler,
public JsBackend,
public SyncEngineEventListener,
public ServerConnectionEventListener,
@@ -72,7 +72,7 @@ class SyncManagerImpl : public SyncManager,
ExtensionsActivityMonitor* extensions_activity_monitor,
SyncManager::ChangeDelegate* change_delegate,
const SyncCredentials& credentials,
- scoped_ptr<SyncNotifier> sync_notifier,
+ scoped_ptr<Invalidator> invalidator,
const std::string& restored_key_for_bootstrapping,
const std::string& restored_keystore_key_for_bootstrapping,
scoped_ptr<InternalComponentsFactory> internal_components_factory,
@@ -89,12 +89,12 @@ class SyncManagerImpl : public SyncManager,
virtual void UpdateEnabledTypes(
const ModelTypeSet& enabled_types) OVERRIDE;
virtual void RegisterInvalidationHandler(
- SyncNotifierObserver* handler) OVERRIDE;
+ InvalidationHandler* handler) OVERRIDE;
virtual void UpdateRegisteredInvalidationIds(
- SyncNotifierObserver* handler,
+ InvalidationHandler* handler,
const ObjectIdSet& ids) OVERRIDE;
virtual void UnregisterInvalidationHandler(
- SyncNotifierObserver* handler) OVERRIDE;
+ InvalidationHandler* handler) OVERRIDE;
virtual void StartSyncingNormally(
const ModelSafeRoutingInfo& routing_info) OVERRIDE;
virtual void ConfigureSyncer(
@@ -167,7 +167,7 @@ class SyncManagerImpl : public SyncManager,
const syncable::ImmutableWriteTransactionInfo& write_transaction_info,
syncable::BaseTransaction* trans) OVERRIDE;
- // SyncNotifierObserver implementation.
+ // InvalidationHandler implementation.
virtual void OnNotificationsEnabled() OVERRIDE;
virtual void OnNotificationsDisabled(
NotificationsDisabledReason reason) OVERRIDE;
@@ -332,8 +332,8 @@ class SyncManagerImpl : public SyncManager,
// Start()ed.
scoped_ptr<SyncScheduler> scheduler_;
- // The SyncNotifier which notifies us when updates need to be downloaded.
- scoped_ptr<SyncNotifier> sync_notifier_;
+ // The Invalidator which notifies us when updates need to be downloaded.
+ scoped_ptr<Invalidator> invalidator_;
// A multi-purpose status watch object that aggregates stats from various
// sync components.